@@ -9,14 +9,14 @@
 #include <QDebug>
 #include <QQmlContext>
 
+#include "kdescendantsproxymodel_qml.h"
+#include "krolenames.h"
 #include "ksortfilterproxymodel.h"
 #include <KColumnHeadersModel>
 #include <KDescendantsProxyModel>
 #include <KNumberModel>
-#if KITEMMODELS_BUILD_DEPRECATED_SINCE(5, 80)
-#include "kconcatenaterowsproxymodel_qml.h"
-#endif
-#include "kdescendantsproxymodel_qml.h"
+
+using namespace Qt::StringLiterals;
 
 void Plugin::initializeEngine(QQmlEngine *engine, const char *uri)
 {
@@ -27,11 +27,15 @@ void Plugin::initializeEngine(QQmlEngine *engine, const char *uri)
 void Plugin::registerTypes(const char *uri)
 {
     qmlRegisterAnonymousType<QAbstractItemModel>(uri, 1);
-#if KITEMMODELS_BUILD_DEPRECATED_SINCE(5, 80)
-    qmlRegisterExtendedType<KConcatenateRowsProxyModel, KConcatenateRowsProxyModelQml>(uri, 1, 0, "KConcatenateRowsProxyModel");
-#endif
+
+    // 1.0
     qmlRegisterType<KDescendantsProxyModelQml>(uri, 1, 0, "KDescendantsProxyModel");
     qmlRegisterType<KNumberModel>(uri, 1, 0, "KNumberModel");
     qmlRegisterType<KColumnHeadersModel>(uri, 1, 0, "KColumnHeadersModel");
     qmlRegisterType<KSortFilterProxyModel>(uri, 1, 0, "KSortFilterProxyModel");
+
+    // 1.1
+    qmlRegisterUncreatableType<KRoleNames>(uri, 1, 1, "KRoleNames", u"KRoleNames can only be used as an attached property"_s);
 }
+
+#include "moc_plugin.cpp"
